.djangocms_gallery .disabled { color: #d3d3d3; }
.djangocms_gallery .viewport { position: absolute; }
.djangocms_gallery .wrapper { position: relative; overflow: hidden; }
.djangocms_gallery article { display: block; }